# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/routing/proto/routing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import error_code_pb2 as modules_dot_common_dot_proto_dot_error__code__pb2
from modules.map.proto import map_parking_space_pb2 as modules_dot_map_dot_proto_dot_map__parking__space__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/routing/proto/routing.proto',
  package='apollo.routing',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#modules/routing/proto/routing.proto\x12\x0e\x61pollo.routing\x1a!modules/common/proto/header.proto\x1a#modules/common/proto/geometry.proto\x1a%modules/common/proto/error_code.proto\x1a)modules/map/proto/map_parking_space.proto\"L\n\x0cLaneWaypoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\t\n\x01s\x18\x02 \x01(\x01\x12%\n\x04pose\x18\x03 \x01(\x0b\x32\x17.apollo.common.PointENU\"9\n\x0bLaneSegment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07start_s\x18\x02 \x01(\x01\x12\r\n\x05\x65nd_s\x18\x03 \x01(\x01\"W\n\x0bParkingInfo\x12\x18\n\x10parking_space_id\x18\x01 \x01(\t\x12.\n\rparking_point\x18\x02 \x01(\x0b\x32\x17.apollo.common.PointENU\"\xbb\x02\n\x0eRoutingRequest\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12.\n\x08waypoint\x18\x02 \x03(\x0b\x32\x1c.apollo.routing.LaneWaypoint\x12\x35\n\x10\x62lacklisted_lane\x18\x03 \x03(\x0b\x32\x1b.apollo.routing.LaneSegment\x12\x18\n\x10\x62lacklisted_road\x18\x04 \x03(\t\x12\x17\n\tbroadcast\x18\x05 \x01(\x08:\x04true\x12\x35\n\rparking_space\x18\x06 \x01(\x0b\x32\x1a.apollo.hdmap.ParkingSpaceB\x02\x18\x01\x12\x31\n\x0cparking_info\x18\x07 \x01(\x0b\x32\x1b.apollo.routing.ParkingInfo\"\x1f\n\x0bMeasurement\x12\x10\n\x08\x64istance\x18\x01 \x01(\x01\"\x8c\x01\n\x07Passage\x12,\n\x07segment\x18\x01 \x03(\x0b\x32\x1b.apollo.routing.LaneSegment\x12\x10\n\x08\x63\x61n_exit\x18\x02 \x01(\x08\x12\x41\n\x10\x63hange_lane_type\x18\x03 \x01(\x0e\x32\x1e.apollo.routing.ChangeLaneType:\x07\x46ORWARD\"C\n\x0bRoadSegment\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x07passage\x18\x02 \x03(\x0b\x32\x17.apollo.routing.Passage\"\x8c\x02\n\x0fRoutingResponse\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12)\n\x04road\x18\x02 \x03(\x0b\x32\x1b.apollo.routing.RoadSegment\x12\x30\n\x0bmeasurement\x18\x03 \x01(\x0b\x32\x1b.apollo.routing.Measurement\x12\x37\n\x0frouting_request\x18\x04 \x01(\x0b\x32\x1e.apollo.routing.RoutingRequest\x12\x13\n\x0bmap_version\x18\x05 \x01(\x0c\x12\'\n\x06status\x18\x06 \x01(\x0b\x32\x17.apollo.common.StatusPb*2\n\x0e\x43hangeLaneType\x12\x0b\n\x07\x46ORWARD\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_error__code__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__parking__space__pb2.DESCRIPTOR,])

_CHANGELANETYPE = _descriptor.EnumDescriptor(
  name='ChangeLaneType',
  full_name='apollo.routing.ChangeLaneType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FORWARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1269,
  serialized_end=1319,
)
_sym_db.RegisterEnumDescriptor(_CHANGELANETYPE)

ChangeLaneType = enum_type_wrapper.EnumTypeWrapper(_CHANGELANETYPE)
FORWARD = 0
LEFT = 1
RIGHT = 2



_LANEWAYPOINT = _descriptor.Descriptor(
  name='LaneWaypoint',
  full_name='apollo.routing.LaneWaypoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.routing.LaneWaypoint.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.routing.LaneWaypoint.s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='apollo.routing.LaneWaypoint.pose', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=285,
)


_LANESEGMENT = _descriptor.Descriptor(
  name='LaneSegment',
  full_name='apollo.routing.LaneSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.routing.LaneSegment.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_s', full_name='apollo.routing.LaneSegment.start_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='apollo.routing.LaneSegment.end_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=344,
)


_PARKINGINFO = _descriptor.Descriptor(
  name='ParkingInfo',
  full_name='apollo.routing.ParkingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parking_space_id', full_name='apollo.routing.ParkingInfo.parking_space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_point', full_name='apollo.routing.ParkingInfo.parking_point', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=433,
)


_ROUTINGREQUEST = _descriptor.Descriptor(
  name='RoutingRequest',
  full_name='apollo.routing.RoutingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.routing.RoutingRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waypoint', full_name='apollo.routing.RoutingRequest.waypoint', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blacklisted_lane', full_name='apollo.routing.RoutingRequest.blacklisted_lane', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blacklisted_road', full_name='apollo.routing.RoutingRequest.blacklisted_road', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast', full_name='apollo.routing.RoutingRequest.broadcast', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_space', full_name='apollo.routing.RoutingRequest.parking_space', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_info', full_name='apollo.routing.RoutingRequest.parking_info', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=751,
)


_MEASUREMENT = _descriptor.Descriptor(
  name='Measurement',
  full_name='apollo.routing.Measurement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance', full_name='apollo.routing.Measurement.distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=784,
)


_PASSAGE = _descriptor.Descriptor(
  name='Passage',
  full_name='apollo.routing.Passage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segment', full_name='apollo.routing.Passage.segment', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_exit', full_name='apollo.routing.Passage.can_exit', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_lane_type', full_name='apollo.routing.Passage.change_lane_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=927,
)


_ROADSEGMENT = _descriptor.Descriptor(
  name='RoadSegment',
  full_name='apollo.routing.RoadSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.routing.RoadSegment.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passage', full_name='apollo.routing.RoadSegment.passage', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=929,
  serialized_end=996,
)


_ROUTINGRESPONSE = _descriptor.Descriptor(
  name='RoutingResponse',
  full_name='apollo.routing.RoutingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.routing.RoutingResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road', full_name='apollo.routing.RoutingResponse.road', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement', full_name='apollo.routing.RoutingResponse.measurement', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_request', full_name='apollo.routing.RoutingResponse.routing_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_version', full_name='apollo.routing.RoutingResponse.map_version', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='apollo.routing.RoutingResponse.status', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=999,
  serialized_end=1267,
)

_LANEWAYPOINT.fields_by_name['pose'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_PARKINGINFO.fields_by_name['parking_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_ROUTINGREQUEST.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_ROUTINGREQUEST.fields_by_name['waypoint'].message_type = _LANEWAYPOINT
_ROUTINGREQUEST.fields_by_name['blacklisted_lane'].message_type = _LANESEGMENT
_ROUTINGREQUEST.fields_by_name['parking_space'].message_type = modules_dot_map_dot_proto_dot_map__parking__space__pb2._PARKINGSPACE
_ROUTINGREQUEST.fields_by_name['parking_info'].message_type = _PARKINGINFO
_PASSAGE.fields_by_name['segment'].message_type = _LANESEGMENT
_PASSAGE.fields_by_name['change_lane_type'].enum_type = _CHANGELANETYPE
_ROADSEGMENT.fields_by_name['passage'].message_type = _PASSAGE
_ROUTINGRESPONSE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_ROUTINGRESPONSE.fields_by_name['road'].message_type = _ROADSEGMENT
_ROUTINGRESPONSE.fields_by_name['measurement'].message_type = _MEASUREMENT
_ROUTINGRESPONSE.fields_by_name['routing_request'].message_type = _ROUTINGREQUEST
_ROUTINGRESPONSE.fields_by_name['status'].message_type = modules_dot_common_dot_proto_dot_error__code__pb2._STATUSPB
DESCRIPTOR.message_types_by_name['LaneWaypoint'] = _LANEWAYPOINT
DESCRIPTOR.message_types_by_name['LaneSegment'] = _LANESEGMENT
DESCRIPTOR.message_types_by_name['ParkingInfo'] = _PARKINGINFO
DESCRIPTOR.message_types_by_name['RoutingRequest'] = _ROUTINGREQUEST
DESCRIPTOR.message_types_by_name['Measurement'] = _MEASUREMENT
DESCRIPTOR.message_types_by_name['Passage'] = _PASSAGE
DESCRIPTOR.message_types_by_name['RoadSegment'] = _ROADSEGMENT
DESCRIPTOR.message_types_by_name['RoutingResponse'] = _ROUTINGRESPONSE
DESCRIPTOR.enum_types_by_name['ChangeLaneType'] = _CHANGELANETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneWaypoint = _reflection.GeneratedProtocolMessageType('LaneWaypoint', (_message.Message,), {
  'DESCRIPTOR' : _LANEWAYPOINT,
  '__module__' : 'modules.routing.proto.routing_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.LaneWaypoint)
  })
_sym_db.RegisterMessage(LaneWaypoint)

LaneSegment = _reflection.GeneratedProtocolMessageType('LaneSegment', (_message.Message,), {
  'DESCRIPTOR' : _LANESEGMENT,
  '__module__' : 'modules.routing.proto.routing_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.LaneSegment)
  })
_sym_db.RegisterMessage(LaneSegment)

ParkingInfo = _reflection.GeneratedProtocolMessageType('ParkingInfo', (_message.Message,), {
  'DESCRIPTOR' : _PARKINGINFO,
  '__module__' : 'modules.routing.proto.routing_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.ParkingInfo)
  })
_sym_db.RegisterMessage(ParkingInfo)

RoutingRequest = _reflection.GeneratedProtocolMessageType('RoutingRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROUTINGREQUEST,
  '__module__' : 'modules.routing.proto.routing_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.RoutingRequest)
  })
_sym_db.RegisterMessage(RoutingRequest)

Measurement = _reflection.GeneratedProtocolMessageType('Measurement', (_message.Message,), {
  'DESCRIPTOR' : _MEASUREMENT,
  '__module__' : 'modules.routing.proto.routing_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.Measurement)
  })
_sym_db.RegisterMessage(Measurement)

Passage = _reflection.GeneratedProtocolMessageType('Passage', (_message.Message,), {
  'DESCRIPTOR' : _PASSAGE,
  '__module__' : 'modules.routing.proto.routing_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.Passage)
  })
_sym_db.RegisterMessage(Passage)

RoadSegment = _reflection.GeneratedProtocolMessageType('RoadSegment', (_message.Message,), {
  'DESCRIPTOR' : _ROADSEGMENT,
  '__module__' : 'modules.routing.proto.routing_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.RoadSegment)
  })
_sym_db.RegisterMessage(RoadSegment)

RoutingResponse = _reflection.GeneratedProtocolMessageType('RoutingResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROUTINGRESPONSE,
  '__module__' : 'modules.routing.proto.routing_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.RoutingResponse)
  })
_sym_db.RegisterMessage(RoutingResponse)


_ROUTINGREQUEST.fields_by_name['parking_space']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/sensor_meta_schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/sensor_meta_schema.proto',
  package='apollo.perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1modules/perception/proto/sensor_meta_schema.proto\x12\x11\x61pollo.perception\"\xad\x04\n\nSensorMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x04type\x18\x02 \x01(\x0e\x32(.apollo.perception.SensorMeta.SensorType\x12\x44\n\x0borientation\x18\x03 \x01(\x0e\x32/.apollo.perception.SensorMeta.SensorOrientation\"\xf7\x01\n\nSensorType\x12 \n\x13UNKNOWN_SENSOR_TYPE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x0f\n\x0bVELODYNE_64\x10\x00\x12\x0f\n\x0bVELODYNE_32\x10\x01\x12\x0f\n\x0bVELODYNE_16\x10\x02\x12\r\n\tLDLIDAR_4\x10\x03\x12\r\n\tLDLIDAR_1\x10\x04\x12\x15\n\x11SHORT_RANGE_RADAR\x10\x05\x12\x14\n\x10LONG_RANGE_RADAR\x10\x06\x12\x14\n\x10MONOCULAR_CAMERA\x10\x07\x12\x11\n\rSTEREO_CAMERA\x10\x08\x12\x0e\n\nULTRASONIC\x10\t\x12\x10\n\x0cVELODYNE_128\x10\n\"\x98\x01\n\x11SensorOrientation\x12\t\n\x05\x46RONT\x10\x00\x12\x10\n\x0cLEFT_FORWARD\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\x11\n\rLEFT_BACKWARD\x10\x03\x12\x08\n\x04REAR\x10\x04\x12\x12\n\x0eRIGHT_BACKWARD\x10\x05\x12\t\n\x05RIGHT\x10\x06\x12\x11\n\rRIGHT_FORWARD\x10\x07\x12\r\n\tPANORAMIC\x10\x08\"E\n\x0fMultiSensorMeta\x12\x32\n\x0bsensor_meta\x18\x01 \x03(\x0b\x32\x1d.apollo.perception.SensorMeta'
)



_SENSORMETA_SENSORTYPE = _descriptor.EnumDescriptor(
  name='SensorType',
  full_name='apollo.perception.SensorMeta.SensorType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_SENSOR_TYPE', index=0, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VELODYNE_64', index=1, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VELODYNE_32', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VELODYNE_16', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDLIDAR_4', index=4, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LDLIDAR_1', index=5, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHORT_RANGE_RADAR', index=6, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LONG_RANGE_RADAR', index=7, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONOCULAR_CAMERA', index=8, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEREO_CAMERA', index=9, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ULTRASONIC', index=10, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VELODYNE_128', index=11, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=228,
  serialized_end=475,
)
_sym_db.RegisterEnumDescriptor(_SENSORMETA_SENSORTYPE)

_SENSORMETA_SENSORORIENTATION = _descriptor.EnumDescriptor(
  name='SensorOrientation',
  full_name='apollo.perception.SensorMeta.SensorOrientation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FRONT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_FORWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_BACKWARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REAR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_BACKWARD', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_FORWARD', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PANORAMIC', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=478,
  serialized_end=630,
)
_sym_db.RegisterEnumDescriptor(_SENSORMETA_SENSORORIENTATION)


_SENSORMETA = _descriptor.Descriptor(
  name='SensorMeta',
  full_name='apollo.perception.SensorMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.SensorMeta.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.perception.SensorMeta.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='apollo.perception.SensorMeta.orientation', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SENSORMETA_SENSORTYPE,
    _SENSORMETA_SENSORORIENTATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=630,
)


_MULTISENSORMETA = _descriptor.Descriptor(
  name='MultiSensorMeta',
  full_name='apollo.perception.MultiSensorMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_meta', full_name='apollo.perception.MultiSensorMeta.sensor_meta', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=701,
)

_SENSORMETA.fields_by_name['type'].enum_type = _SENSORMETA_SENSORTYPE
_SENSORMETA.fields_by_name['orientation'].enum_type = _SENSORMETA_SENSORORIENTATION
_SENSORMETA_SENSORTYPE.containing_type = _SENSORMETA
_SENSORMETA_SENSORORIENTATION.containing_type = _SENSORMETA
_MULTISENSORMETA.fields_by_name['sensor_meta'].message_type = _SENSORMETA
DESCRIPTOR.message_types_by_name['SensorMeta'] = _SENSORMETA
DESCRIPTOR.message_types_by_name['MultiSensorMeta'] = _MULTISENSORMETA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SensorMeta = _reflection.GeneratedProtocolMessageType('SensorMeta', (_message.Message,), {
  'DESCRIPTOR' : _SENSORMETA,
  '__module__' : 'modules.perception.proto.sensor_meta_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.SensorMeta)
  })
_sym_db.RegisterMessage(SensorMeta)

MultiSensorMeta = _reflection.GeneratedProtocolMessageType('MultiSensorMeta', (_message.Message,), {
  'DESCRIPTOR' : _MULTISENSORMETA,
  '__module__' : 'modules.perception.proto.sensor_meta_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.MultiSensorMeta)
  })
_sym_db.RegisterMessage(MultiSensorMeta)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/decision.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import vehicle_signal_pb2 as modules_dot_common_dot_proto_dot_vehicle__signal__pb2
from modules.routing.proto import routing_pb2 as modules_dot_routing_dot_proto_dot_routing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/decision.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/planning/proto/decision.proto\x12\x0f\x61pollo.planning\x1a#modules/common/proto/geometry.proto\x1a)modules/common/proto/vehicle_signal.proto\x1a#modules/routing/proto/routing.proto\"M\n\nTargetLane\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07start_s\x18\x02 \x01(\x01\x12\r\n\x05\x65nd_s\x18\x03 \x01(\x01\x12\x13\n\x0bspeed_limit\x18\x04 \x01(\x01\"\x0e\n\x0cObjectIgnore\"\xb4\x01\n\nObjectStop\x12\x34\n\x0breason_code\x18\x01 \x01(\x0e\x32\x1f.apollo.planning.StopReasonCode\x12\x12\n\ndistance_s\x18\x02 \x01(\x01\x12+\n\nstop_point\x18\x03 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\x14\n\x0cstop_heading\x18\x04 \x01(\x01\x12\x19\n\x11wait_for_obstacle\x18\x05 \x03(\t\"\xac\x01\n\x0bObjectNudge\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.apollo.planning.ObjectNudge.Type\x12\x12\n\ndistance_l\x18\x02 \x01(\x01\"X\n\x04Type\x12\x0e\n\nLEFT_NUDGE\x10\x01\x12\x0f\n\x0bRIGHT_NUDGE\x10\x02\x12\x16\n\x12\x44YNAMIC_LEFT_NUDGE\x10\x03\x12\x17\n\x13\x44YNAMIC_RIGHT_NUDGE\x10\x04\"{\n\x0bObjectYield\x12\x12\n\ndistance_s\x18\x01 \x01(\x01\x12,\n\x0b\x66\x65nce_point\x18\x02 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\x15\n\rfence_heading\x18\x03 \x01(\x01\x12\x13\n\x0btime_buffer\x18\x04 \x01(\x01\"g\n\x0cObjectFollow\x12\x12\n\ndistance_s\x18\x01 \x01(\x01\x12,\n\x0b\x66\x65nce_point\x18\x02 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\x15\n\rfence_heading\x18\x03 \x01(\x01\"~\n\x0eObjectOvertake\x12\x12\n\ndistance_s\x18\x01 \x01(\x01\x12,\n\x0b\x66\x65nce_point\x18\x02 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\x15\n\rfence_heading\x18\x03 \x01(\x01\x12\x13\n\x0btime_buffer\x18\x04 \x01(\x01\"a\n\x0eObjectSidePass\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.apollo.planning.ObjectSidePass.Type\"\x1b\n\x04Type\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\"\r\n\x0bObjectAvoid\"\x82\x01\n\x0cObjectStatus\x12\x36\n\x0bmotion_type\x18\x01 \x01(\x0b\x32!.apollo.planning.ObjectMotionType\x12:\n\rdecision_type\x18\x02 \x01(\x0b\x32#.apollo.planning.ObjectDecisionType\"\x0e\n\x0cObjectStatic\"\x0f\n\rObjectDynamic\"\x84\x01\n\x10ObjectMotionType\x12/\n\x06static\x18\x01 \x01(\x0b\x32\x1d.apollo.planning.ObjectStaticH\x00\x12\x31\n\x07\x64ynamic\x18\x02 \x01(\x0b\x32\x1e.apollo.planning.ObjectDynamicH\x00\x42\x0c\n\nmotion_tag\"\xa9\x03\n\x12ObjectDecisionType\x12/\n\x06ignore\x18\x01 \x01(\x0b\x32\x1d.apollo.planning.ObjectIgnoreH\x00\x12+\n\x04stop\x18\x02 \x01(\x0b\x32\x1b.apollo.planning.ObjectStopH\x00\x12/\n\x06\x66ollow\x18\x03 \x01(\x0b\x32\x1d.apollo.planning.ObjectFollowH\x00\x12-\n\x05yield\x18\x04 \x01(\x0b\x32\x1c.apollo.planning.ObjectYieldH\x00\x12\x33\n\x08overtake\x18\x05 \x01(\x0b\x32\x1f.apollo.planning.ObjectOvertakeH\x00\x12-\n\x05nudge\x18\x06 \x01(\x0b\x32\x1c.apollo.planning.ObjectNudgeH\x00\x12-\n\x05\x61void\x18\x07 \x01(\x0b\x32\x1c.apollo.planning.ObjectAvoidH\x00\x12\x34\n\tside_pass\x18\x08 \x01(\x0b\x32\x1f.apollo.planning.ObjectSidePassH\x00\x42\x0c\n\nobject_tag\"q\n\x0eObjectDecision\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rperception_id\x18\x02 \x01(\x05\x12<\n\x0fobject_decision\x18\x03 \x03(\x0b\x32#.apollo.planning.ObjectDecisionType\"D\n\x0fObjectDecisions\x12\x31\n\x08\x64\x65\x63ision\x18\x01 \x03(\x0b\x32\x1f.apollo.planning.ObjectDecision\"\xcd\x01\n\x08MainStop\x12\x34\n\x0breason_code\x18\x01 \x01(\x0e\x32\x1f.apollo.planning.StopReasonCode\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12+\n\nstop_point\x18\x03 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\x14\n\x0cstop_heading\x18\x04 \x01(\x01\x12\x38\n\x10\x63hange_lane_type\x18\x05 \x01(\x0e\x32\x1e.apollo.routing.ChangeLaneType\"\x18\n\x16\x45mergencyStopHardBrake\"\x1b\n\x19\x45mergencyStopCruiseToStop\"\x9f\x03\n\x11MainEmergencyStop\x12\x42\n\x0breason_code\x18\x01 \x01(\x0e\x32-.apollo.planning.MainEmergencyStop.ReasonCode\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12=\n\nhard_brake\x18\x03 \x01(\x0b\x32\'.apollo.planning.EmergencyStopHardBrakeH\x00\x12\x44\n\x0e\x63ruise_to_stop\x18\x04 \x01(\x0b\x32*.apollo.planning.EmergencyStopCruiseToStopH\x00\"\xa8\x01\n\nReasonCode\x12\x1d\n\x19\x45STOP_REASON_INTERNAL_ERR\x10\x01\x12\x1a\n\x16\x45STOP_REASON_COLLISION\x10\x02\x12\x1d\n\x19\x45STOP_REASON_ST_FIND_PATH\x10\x03\x12!\n\x1d\x45STOP_REASON_ST_MAKE_DECISION\x10\x04\x12\x1d\n\x19\x45STOP_REASON_SENSOR_ERROR\x10\x05\x42\x06\n\x04task\"F\n\nMainCruise\x12\x38\n\x10\x63hange_lane_type\x18\x01 \x01(\x0e\x32\x1e.apollo.routing.ChangeLaneType\"\xff\x01\n\x0eMainChangeLane\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.apollo.planning.MainChangeLane.Type\x12\x31\n\x0c\x64\x65\x66\x61ult_lane\x18\x02 \x03(\x0b\x32\x1b.apollo.planning.TargetLane\x12\x34\n\x11\x64\x65\x66\x61ult_lane_stop\x18\x03 \x01(\x0b\x32\x19.apollo.planning.MainStop\x12\x33\n\x10target_lane_stop\x18\x04 \x01(\x0b\x32\x19.apollo.planning.MainStop\"\x1b\n\x04Type\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\"X\n\x13MainMissionComplete\x12+\n\nstop_point\x18\x01 \x01(\x0b\x32\x17.apollo.common.PointENU\x12\x14\n\x0cstop_heading\x18\x02 \x01(\x01\"\x1e\n\x0cMainNotReady\x12\x0e\n\x06reason\x18\x01 \x01(\t\"j\n\x0bMainParking\x12:\n\x06status\x18\x01 \x01(\x0e\x32*.apollo.planning.MainParking.ParkingStatus\"\x1f\n\rParkingStatus\x12\x0e\n\nIN_PARKING\x10\x01\"\xbe\x03\n\x0cMainDecision\x12-\n\x06\x63ruise\x18\x01 \x01(\x0b\x32\x1b.apollo.planning.MainCruiseH\x00\x12)\n\x04stop\x18\x02 \x01(\x0b\x32\x19.apollo.planning.MainStopH\x00\x12\x33\n\x05\x65stop\x18\x03 \x01(\x0b\x32\".apollo.planning.MainEmergencyStopH\x00\x12:\n\x0b\x63hange_lane\x18\x04 \x01(\x0b\x32\x1f.apollo.planning.MainChangeLaneB\x02\x18\x01H\x00\x12@\n\x10mission_complete\x18\x06 \x01(\x0b\x32$.apollo.planning.MainMissionCompleteH\x00\x12\x32\n\tnot_ready\x18\x07 \x01(\x0b\x32\x1d.apollo.planning.MainNotReadyH\x00\x12/\n\x07parking\x18\x08 \x01(\x0b\x32\x1c.apollo.planning.MainParkingH\x00\x12\x34\n\x0btarget_lane\x18\x05 \x03(\x0b\x32\x1b.apollo.planning.TargetLaneB\x02\x18\x01\x42\x06\n\x04task\"\xb7\x01\n\x0e\x44\x65\x63isionResult\x12\x34\n\rmain_decision\x18\x01 \x01(\x0b\x32\x1d.apollo.planning.MainDecision\x12\x39\n\x0fobject_decision\x18\x02 \x01(\x0b\x32 .apollo.planning.ObjectDecisions\x12\x34\n\x0evehicle_signal\x18\x03 \x01(\x0b\x32\x1c.apollo.common.VehicleSignal*\x9e\x04\n\x0eStopReasonCode\x12\x1c\n\x18STOP_REASON_HEAD_VEHICLE\x10\x01\x12\x1b\n\x17STOP_REASON_DESTINATION\x10\x02\x12\x1a\n\x16STOP_REASON_PEDESTRIAN\x10\x03\x12\x18\n\x14STOP_REASON_OBSTACLE\x10\x04\x12\x1a\n\x16STOP_REASON_PREPARKING\x10\x05\x12\x16\n\x12STOP_REASON_SIGNAL\x10\x64\x12\x19\n\x15STOP_REASON_STOP_SIGN\x10\x65\x12\x1a\n\x16STOP_REASON_YIELD_SIGN\x10\x66\x12\x1a\n\x16STOP_REASON_CLEAR_ZONE\x10g\x12\x19\n\x15STOP_REASON_CROSSWALK\x10h\x12\x17\n\x13STOP_REASON_CREEPER\x10i\x12\x1d\n\x19STOP_REASON_REFERENCE_END\x10j\x12\x1d\n\x19STOP_REASON_YELLOW_SIGNAL\x10k\x12\x19\n\x15STOP_REASON_PULL_OVER\x10l\x12\x1f\n\x1bSTOP_REASON_SIDEPASS_SAFETY\x10m\x12$\n\x1fSTOP_REASON_PRE_OPEN_SPACE_STOP\x10\xc8\x01\x12$\n\x1fSTOP_REASON_LANE_CHANGE_URGENCY\x10\xc9\x01\x12\x1a\n\x15STOP_REASON_EMERGENCY\x10\xca\x01'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_vehicle__signal__pb2.DESCRIPTOR,modules_dot_routing_dot_proto_dot_routing__pb2.DESCRIPTOR,])

_STOPREASONCODE = _descriptor.EnumDescriptor(
  name='StopReasonCode',
  full_name='apollo.planning.StopReasonCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_HEAD_VEHICLE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_DESTINATION', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_PEDESTRIAN', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_OBSTACLE', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_PREPARKING', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_SIGNAL', index=5, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_STOP_SIGN', index=6, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_YIELD_SIGN', index=7, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_CLEAR_ZONE', index=8, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_CROSSWALK', index=9, number=104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_CREEPER', index=10, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_REFERENCE_END', index=11, number=106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_YELLOW_SIGNAL', index=12, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_PULL_OVER', index=13, number=108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_SIDEPASS_SAFETY', index=14, number=109,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_PRE_OPEN_SPACE_STOP', index=15, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_LANE_CHANGE_URGENCY', index=16, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_EMERGENCY', index=17, number=202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3891,
  serialized_end=4433,
)
_sym_db.RegisterEnumDescriptor(_STOPREASONCODE)

StopReasonCode = enum_type_wrapper.EnumTypeWrapper(_STOPREASONCODE)
STOP_REASON_HEAD_VEHICLE = 1
STOP_REASON_DESTINATION = 2
STOP_REASON_PEDESTRIAN = 3
STOP_REASON_OBSTACLE = 4
STOP_REASON_PREPARKING = 5
STOP_REASON_SIGNAL = 100
STOP_REASON_STOP_SIGN = 101
STOP_REASON_YIELD_SIGN = 102
STOP_REASON_CLEAR_ZONE = 103
STOP_REASON_CROSSWALK = 104
STOP_REASON_CREEPER = 105
STOP_REASON_REFERENCE_END = 106
STOP_REASON_YELLOW_SIGNAL = 107
STOP_REASON_PULL_OVER = 108
STOP_REASON_SIDEPASS_SAFETY = 109
STOP_REASON_PRE_OPEN_SPACE_STOP = 200
STOP_REASON_LANE_CHANGE_URGENCY = 201
STOP_REASON_EMERGENCY = 202


_OBJECTNUDGE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.planning.ObjectNudge.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFT_NUDGE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_NUDGE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_LEFT_NUDGE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_RIGHT_NUDGE', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=538,
  serialized_end=626,
)
_sym_db.RegisterEnumDescriptor(_OBJECTNUDGE_TYPE)

_OBJECTSIDEPASS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.planning.ObjectSidePass.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1056,
  serialized_end=1083,
)
_sym_db.RegisterEnumDescriptor(_OBJECTSIDEPASS_TYPE)

_MAINEMERGENCYSTOP_REASONCODE = _descriptor.EnumDescriptor(
  name='ReasonCode',
  full_name='apollo.planning.MainEmergencyStop.ReasonCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ESTOP_REASON_INTERNAL_ERR', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESTOP_REASON_COLLISION', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESTOP_REASON_ST_FIND_PATH', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESTOP_REASON_ST_MAKE_DECISION', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESTOP_REASON_SENSOR_ERROR', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2517,
  serialized_end=2685,
)
_sym_db.RegisterEnumDescriptor(_MAINEMERGENCYSTOP_REASONCODE)

_MAINCHANGELANE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.planning.MainChangeLane.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1056,
  serialized_end=1083,
)
_sym_db.RegisterEnumDescriptor(_MAINCHANGELANE_TYPE)

_MAINPARKING_PARKINGSTATUS = _descriptor.EnumDescriptor(
  name='ParkingStatus',
  full_name='apollo.planning.MainParking.ParkingStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IN_PARKING', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3222,
  serialized_end=3253,
)
_sym_db.RegisterEnumDescriptor(_MAINPARKING_PARKINGSTATUS)


_TARGETLANE = _descriptor.Descriptor(
  name='TargetLane',
  full_name='apollo.planning.TargetLane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.planning.TargetLane.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_s', full_name='apollo.planning.TargetLane.start_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='apollo.planning.TargetLane.end_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.planning.TargetLane.speed_limit', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=252,
)


_OBJECTIGNORE = _descriptor.Descriptor(
  name='ObjectIgnore',
  full_name='apollo.planning.ObjectIgnore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=268,
)


_OBJECTSTOP = _descriptor.Descriptor(
  name='ObjectStop',
  full_name='apollo.planning.ObjectStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason_code', full_name='apollo.planning.ObjectStop.reason_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_s', full_name='apollo.planning.ObjectStop.distance_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_point', full_name='apollo.planning.ObjectStop.stop_point', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_heading', full_name='apollo.planning.ObjectStop.stop_heading', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_for_obstacle', full_name='apollo.planning.ObjectStop.wait_for_obstacle', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=451,
)


_OBJECTNUDGE = _descriptor.Descriptor(
  name='ObjectNudge',
  full_name='apollo.planning.ObjectNudge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.planning.ObjectNudge.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_l', full_name='apollo.planning.ObjectNudge.distance_l', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBJECTNUDGE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=626,
)


_OBJECTYIELD = _descriptor.Descriptor(
  name='ObjectYield',
  full_name='apollo.planning.ObjectYield',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance_s', full_name='apollo.planning.ObjectYield.distance_s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fence_point', full_name='apollo.planning.ObjectYield.fence_point', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fence_heading', full_name='apollo.planning.ObjectYield.fence_heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_buffer', full_name='apollo.planning.ObjectYield.time_buffer', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=751,
)


_OBJECTFOLLOW = _descriptor.Descriptor(
  name='ObjectFollow',
  full_name='apollo.planning.ObjectFollow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance_s', full_name='apollo.planning.ObjectFollow.distance_s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fence_point', full_name='apollo.planning.ObjectFollow.fence_point', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fence_heading', full_name='apollo.planning.ObjectFollow.fence_heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=856,
)


_OBJECTOVERTAKE = _descriptor.Descriptor(
  name='ObjectOvertake',
  full_name='apollo.planning.ObjectOvertake',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance_s', full_name='apollo.planning.ObjectOvertake.distance_s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fence_point', full_name='apollo.planning.ObjectOvertake.fence_point', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fence_heading', full_name='apollo.planning.ObjectOvertake.fence_heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_buffer', full_name='apollo.planning.ObjectOvertake.time_buffer', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=858,
  serialized_end=984,
)


_OBJECTSIDEPASS = _descriptor.Descriptor(
  name='ObjectSidePass',
  full_name='apollo.planning.ObjectSidePass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.planning.ObjectSidePass.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBJECTSIDEPASS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=986,
  serialized_end=1083,
)


_OBJECTAVOID = _descriptor.Descriptor(
  name='ObjectAvoid',
  full_name='apollo.planning.ObjectAvoid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1085,
  serialized_end=1098,
)


_OBJECTSTATUS = _descriptor.Descriptor(
  name='ObjectStatus',
  full_name='apollo.planning.ObjectStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='motion_type', full_name='apollo.planning.ObjectStatus.motion_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decision_type', full_name='apollo.planning.ObjectStatus.decision_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1231,
)


_OBJECTSTATIC = _descriptor.Descriptor(
  name='ObjectStatic',
  full_name='apollo.planning.ObjectStatic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1233,
  serialized_end=1247,
)


_OBJECTDYNAMIC = _descriptor.Descriptor(
  name='ObjectDynamic',
  full_name='apollo.planning.ObjectDynamic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1249,
  serialized_end=1264,
)


_OBJECTMOTIONTYPE = _descriptor.Descriptor(
  name='ObjectMotionType',
  full_name='apollo.planning.ObjectMotionType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='static', full_name='apollo.planning.ObjectMotionType.static', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic', full_name='apollo.planning.ObjectMotionType.dynamic', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='motion_tag', full_name='apollo.planning.ObjectMotionType.motion_tag',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1267,
  serialized_end=1399,
)


_OBJECTDECISIONTYPE = _descriptor.Descriptor(
  name='ObjectDecisionType',
  full_name='apollo.planning.ObjectDecisionType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore', full_name='apollo.planning.ObjectDecisionType.ignore', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop', full_name='apollo.planning.ObjectDecisionType.stop', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='follow', full_name='apollo.planning.ObjectDecisionType.follow', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield', full_name='apollo.planning.ObjectDecisionType.yield', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overtake', full_name='apollo.planning.ObjectDecisionType.overtake', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nudge', full_name='apollo.planning.ObjectDecisionType.nudge', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avoid', full_name='apollo.planning.ObjectDecisionType.avoid', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side_pass', full_name='apollo.planning.ObjectDecisionType.side_pass', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='object_tag', full_name='apollo.planning.ObjectDecisionType.object_tag',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1402,
  serialized_end=1827,
)


_OBJECTDECISION = _descriptor.Descriptor(
  name='ObjectDecision',
  full_name='apollo.planning.ObjectDecision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.planning.ObjectDecision.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_id', full_name='apollo.planning.ObjectDecision.perception_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_decision', full_name='apollo.planning.ObjectDecision.object_decision', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1829,
  serialized_end=1942,
)


_OBJECTDECISIONS = _descriptor.Descriptor(
  name='ObjectDecisions',
  full_name='apollo.planning.ObjectDecisions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='decision', full_name='apollo.planning.ObjectDecisions.decision', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1944,
  serialized_end=2012,
)


_MAINSTOP = _descriptor.Descriptor(
  name='MainStop',
  full_name='apollo.planning.MainStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason_code', full_name='apollo.planning.MainStop.reason_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='apollo.planning.MainStop.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_point', full_name='apollo.planning.MainStop.stop_point', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_heading', full_name='apollo.planning.MainStop.stop_heading', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_lane_type', full_name='apollo.planning.MainStop.change_lane_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2015,
  serialized_end=2220,
)


_EMERGENCYSTOPHARDBRAKE = _descriptor.Descriptor(
  name='EmergencyStopHardBrake',
  full_name='apollo.planning.EmergencyStopHardBrake',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2222,
  serialized_end=2246,
)


_EMERGENCYSTOPCRUISETOSTOP = _descriptor.Descriptor(
  name='EmergencyStopCruiseToStop',
  full_name='apollo.planning.EmergencyStopCruiseToStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2248,
  serialized_end=2275,
)


_MAINEMERGENCYSTOP = _descriptor.Descriptor(
  name='MainEmergencyStop',
  full_name='apollo.planning.MainEmergencyStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason_code', full_name='apollo.planning.MainEmergencyStop.reason_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='apollo.planning.MainEmergencyStop.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hard_brake', full_name='apollo.planning.MainEmergencyStop.hard_brake', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cruise_to_stop', full_name='apollo.planning.MainEmergencyStop.cruise_to_stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MAINEMERGENCYSTOP_REASONCODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='task', full_name='apollo.planning.MainEmergencyStop.task',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2278,
  serialized_end=2693,
)


_MAINCRUISE = _descriptor.Descriptor(
  name='MainCruise',
  full_name='apollo.planning.MainCruise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_lane_type', full_name='apollo.planning.MainCruise.change_lane_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2695,
  serialized_end=2765,
)


_MAINCHANGELANE = _descriptor.Descriptor(
  name='MainChangeLane',
  full_name='apollo.planning.MainChangeLane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.planning.MainChangeLane.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_lane', full_name='apollo.planning.MainChangeLane.default_lane', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_lane_stop', full_name='apollo.planning.MainChangeLane.default_lane_stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_lane_stop', full_name='apollo.planning.MainChangeLane.target_lane_stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MAINCHANGELANE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2768,
  serialized_end=3023,
)


_MAINMISSIONCOMPLETE = _descriptor.Descriptor(
  name='MainMissionComplete',
  full_name='apollo.planning.MainMissionComplete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_point', full_name='apollo.planning.MainMissionComplete.stop_point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_heading', full_name='apollo.planning.MainMissionComplete.stop_heading', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3025,
  serialized_end=3113,
)


_MAINNOTREADY = _descriptor.Descriptor(
  name='MainNotReady',
  full_name='apollo.planning.MainNotReady',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason', full_name='apollo.planning.MainNotReady.reason', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3115,
  serialized_end=3145,
)


_MAINPARKING = _descriptor.Descriptor(
  name='MainParking',
  full_name='apollo.planning.MainParking',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='apollo.planning.MainParking.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MAINPARKING_PARKINGSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3147,
  serialized_end=3253,
)


_MAINDECISION = _descriptor.Descriptor(
  name='MainDecision',
  full_name='apollo.planning.MainDecision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cruise', full_name='apollo.planning.MainDecision.cruise', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop', full_name='apollo.planning.MainDecision.stop', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estop', full_name='apollo.planning.MainDecision.estop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_lane', full_name='apollo.planning.MainDecision.change_lane', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_complete', full_name='apollo.planning.MainDecision.mission_complete', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_ready', full_name='apollo.planning.MainDecision.not_ready', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking', full_name='apollo.planning.MainDecision.parking', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_lane', full_name='apollo.planning.MainDecision.target_lane', index=7,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='task', full_name='apollo.planning.MainDecision.task',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3256,
  serialized_end=3702,
)


_DECISIONRESULT = _descriptor.Descriptor(
  name='DecisionResult',
  full_name='apollo.planning.DecisionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='main_decision', full_name='apollo.planning.DecisionResult.main_decision', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_decision', full_name='apollo.planning.DecisionResult.object_decision', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_signal', full_name='apollo.planning.DecisionResult.vehicle_signal', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3705,
  serialized_end=3888,
)

_OBJECTSTOP.fields_by_name['reason_code'].enum_type = _STOPREASONCODE
_OBJECTSTOP.fields_by_name['stop_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_OBJECTNUDGE.fields_by_name['type'].enum_type = _OBJECTNUDGE_TYPE
_OBJECTNUDGE_TYPE.containing_type = _OBJECTNUDGE
_OBJECTYIELD.fields_by_name['fence_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_OBJECTFOLLOW.fields_by_name['fence_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_OBJECTOVERTAKE.fields_by_name['fence_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_OBJECTSIDEPASS.fields_by_name['type'].enum_type = _OBJECTSIDEPASS_TYPE
_OBJECTSIDEPASS_TYPE.containing_type = _OBJECTSIDEPASS
_OBJECTSTATUS.fields_by_name['motion_type'].message_type = _OBJECTMOTIONTYPE
_OBJECTSTATUS.fields_by_name['decision_type'].message_type = _OBJECTDECISIONTYPE
_OBJECTMOTIONTYPE.fields_by_name['static'].message_type = _OBJECTSTATIC
_OBJECTMOTIONTYPE.fields_by_name['dynamic'].message_type = _OBJECTDYNAMIC
_OBJECTMOTIONTYPE.oneofs_by_name['motion_tag'].fields.append(
  _OBJECTMOTIONTYPE.fields_by_name['static'])
_OBJECTMOTIONTYPE.fields_by_name['static'].containing_oneof = _OBJECTMOTIONTYPE.oneofs_by_name['motion_tag']
_OBJECTMOTIONTYPE.oneofs_by_name['motion_tag'].fields.append(
  _OBJECTMOTIONTYPE.fields_by_name['dynamic'])
_OBJECTMOTIONTYPE.fields_by_name['dynamic'].containing_oneof = _OBJECTMOTIONTYPE.oneofs_by_name['motion_tag']
_OBJECTDECISIONTYPE.fields_by_name['ignore'].message_type = _OBJECTIGNORE
_OBJECTDECISIONTYPE.fields_by_name['stop'].message_type = _OBJECTSTOP
_OBJECTDECISIONTYPE.fields_by_name['follow'].message_type = _OBJECTFOLLOW
_OBJECTDECISIONTYPE.fields_by_name['yield'].message_type = _OBJECTYIELD
_OBJECTDECISIONTYPE.fields_by_name['overtake'].message_type = _OBJECTOVERTAKE
_OBJECTDECISIONTYPE.fields_by_name['nudge'].message_type = _OBJECTNUDGE
_OBJECTDECISIONTYPE.fields_by_name['avoid'].message_type = _OBJECTAVOID
_OBJECTDECISIONTYPE.fields_by_name['side_pass'].message_type = _OBJECTSIDEPASS
_OBJECTDECISIONTYPE.oneofs_by_name['object_tag'].fields.append(
  _OBJECTDECISIONTYPE.fields_by_name['ignore'])
_OBJECTDECISIONTYPE.fields_by_name['ignore'].containing_oneof = _OBJECTDECISIONTYPE.oneofs_by_name['object_tag']
_OBJECTDECISIONTYPE.oneofs_by_name['object_tag'].fields.append(
  _OBJECTDECISIONTYPE.fields_by_name['stop'])
_OBJECTDECISIONTYPE.fields_by_name['stop'].containing_oneof = _OBJECTDECISIONTYPE.oneofs_by_name['object_tag']
_OBJECTDECISIONTYPE.oneofs_by_name['object_tag'].fields.append(
  _OBJECTDECISIONTYPE.fields_by_name['follow'])
_OBJECTDECISIONTYPE.fields_by_name['follow'].containing_oneof = _OBJECTDECISIONTYPE.oneofs_by_name['object_tag']
_OBJECTDECISIONTYPE.oneofs_by_name['object_tag'].fields.append(
  _OBJECTDECISIONTYPE.fields_by_name['yield'])
_OBJECTDECISIONTYPE.fields_by_name['yield'].containing_oneof = _OBJECTDECISIONTYPE.oneofs_by_name['object_tag']
_OBJECTDECISIONTYPE.oneofs_by_name['object_tag'].fields.append(
  _OBJECTDECISIONTYPE.fields_by_name['overtake'])
_OBJECTDECISIONTYPE.fields_by_name['overtake'].containing_oneof = _OBJECTDECISIONTYPE.oneofs_by_name['object_tag']
_OBJECTDECISIONTYPE.oneofs_by_name['object_tag'].fields.append(
  _OBJECTDECISIONTYPE.fields_by_name['nudge'])
_OBJECTDECISIONTYPE.fields_by_name['nudge'].containing_oneof = _OBJECTDECISIONTYPE.oneofs_by_name['object_tag']
_OBJECTDECISIONTYPE.oneofs_by_name['object_tag'].fields.append(
  _OBJECTDECISIONTYPE.fields_by_name['avoid'])
_OBJECTDECISIONTYPE.fields_by_name['avoid'].containing_oneof = _OBJECTDECISIONTYPE.oneofs_by_name['object_tag']
_OBJECTDECISIONTYPE.oneofs_by_name['object_tag'].fields.append(
  _OBJECTDECISIONTYPE.fields_by_name['side_pass'])
_OBJECTDECISIONTYPE.fields_by_name['side_pass'].containing_oneof = _OBJECTDECISIONTYPE.oneofs_by_name['object_tag']
_OBJECTDECISION.fields_by_name['object_decision'].message_type = _OBJECTDECISIONTYPE
_OBJECTDECISIONS.fields_by_name['decision'].message_type = _OBJECTDECISION
_MAINSTOP.fields_by_name['reason_code'].enum_type = _STOPREASONCODE
_MAINSTOP.fields_by_name['stop_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_MAINSTOP.fields_by_name['change_lane_type'].enum_type = modules_dot_routing_dot_proto_dot_routing__pb2._CHANGELANETYPE
_MAINEMERGENCYSTOP.fields_by_name['reason_code'].enum_type = _MAINEMERGENCYSTOP_REASONCODE
_MAINEMERGENCYSTOP.fields_by_name['hard_brake'].message_type = _EMERGENCYSTOPHARDBRAKE
_MAINEMERGENCYSTOP.fields_by_name['cruise_to_stop'].message_type = _EMERGENCYSTOPCRUISETOSTOP
_MAINEMERGENCYSTOP_REASONCODE.containing_type = _MAINEMERGENCYSTOP
_MAINEMERGENCYSTOP.oneofs_by_name['task'].fields.append(
  _MAINEMERGENCYSTOP.fields_by_name['hard_brake'])
_MAINEMERGENCYSTOP.fields_by_name['hard_brake'].containing_oneof = _MAINEMERGENCYSTOP.oneofs_by_name['task']
_MAINEMERGENCYSTOP.oneofs_by_name['task'].fields.append(
  _MAINEMERGENCYSTOP.fields_by_name['cruise_to_stop'])
_MAINEMERGENCYSTOP.fields_by_name['cruise_to_stop'].containing_oneof = _MAINEMERGENCYSTOP.oneofs_by_name['task']
_MAINCRUISE.fields_by_name['change_lane_type'].enum_type = modules_dot_routing_dot_proto_dot_routing__pb2._CHANGELANETYPE
_MAINCHANGELANE.fields_by_name['type'].enum_type = _MAINCHANGELANE_TYPE
_MAINCHANGELANE.fields_by_name['default_lane'].message_type = _TARGETLANE
_MAINCHANGELANE.fields_by_name['default_lane_stop'].message_type = _MAINSTOP
_MAINCHANGELANE.fields_by_name['target_lane_stop'].message_type = _MAINSTOP
_MAINCHANGELANE_TYPE.containing_type = _MAINCHANGELANE
_MAINMISSIONCOMPLETE.fields_by_name['stop_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTENU
_MAINPARKING.fields_by_name['status'].enum_type = _MAINPARKING_PARKINGSTATUS
_MAINPARKING_PARKINGSTATUS.containing_type = _MAINPARKING
_MAINDECISION.fields_by_name['cruise'].message_type = _MAINCRUISE
_MAINDECISION.fields_by_name['stop'].message_type = _MAINSTOP
_MAINDECISION.fields_by_name['estop'].message_type = _MAINEMERGENCYSTOP
_MAINDECISION.fields_by_name['change_lane'].message_type = _MAINCHANGELANE
_MAINDECISION.fields_by_name['mission_complete'].message_type = _MAINMISSIONCOMPLETE
_MAINDECISION.fields_by_name['not_ready'].message_type = _MAINNOTREADY
_MAINDECISION.fields_by_name['parking'].message_type = _MAINPARKING
_MAINDECISION.fields_by_name['target_lane'].message_type = _TARGETLANE
_MAINDECISION.oneofs_by_name['task'].fields.append(
  _MAINDECISION.fields_by_name['cruise'])
_MAINDECISION.fields_by_name['cruise'].containing_oneof = _MAINDECISION.oneofs_by_name['task']
_MAINDECISION.oneofs_by_name['task'].fields.append(
  _MAINDECISION.fields_by_name['stop'])
_MAINDECISION.fields_by_name['stop'].containing_oneof = _MAINDECISION.oneofs_by_name['task']
_MAINDECISION.oneofs_by_name['task'].fields.append(
  _MAINDECISION.fields_by_name['estop'])
_MAINDECISION.fields_by_name['estop'].containing_oneof = _MAINDECISION.oneofs_by_name['task']
_MAINDECISION.oneofs_by_name['task'].fields.append(
  _MAINDECISION.fields_by_name['change_lane'])
_MAINDECISION.fields_by_name['change_lane'].containing_oneof = _MAINDECISION.oneofs_by_name['task']
_MAINDECISION.oneofs_by_name['task'].fields.append(
  _MAINDECISION.fields_by_name['mission_complete'])
_MAINDECISION.fields_by_name['mission_complete'].containing_oneof = _MAINDECISION.oneofs_by_name['task']
_MAINDECISION.oneofs_by_name['task'].fields.append(
  _MAINDECISION.fields_by_name['not_ready'])
_MAINDECISION.fields_by_name['not_ready'].containing_oneof = _MAINDECISION.oneofs_by_name['task']
_MAINDECISION.oneofs_by_name['task'].fields.append(
  _MAINDECISION.fields_by_name['parking'])
_MAINDECISION.fields_by_name['parking'].containing_oneof = _MAINDECISION.oneofs_by_name['task']
_DECISIONRESULT.fields_by_name['main_decision'].message_type = _MAINDECISION
_DECISIONRESULT.fields_by_name['object_decision'].message_type = _OBJECTDECISIONS
_DECISIONRESULT.fields_by_name['vehicle_signal'].message_type = modules_dot_common_dot_proto_dot_vehicle__signal__pb2._VEHICLESIGNAL
DESCRIPTOR.message_types_by_name['TargetLane'] = _TARGETLANE
DESCRIPTOR.message_types_by_name['ObjectIgnore'] = _OBJECTIGNORE
DESCRIPTOR.message_types_by_name['ObjectStop'] = _OBJECTSTOP
DESCRIPTOR.message_types_by_name['ObjectNudge'] = _OBJECTNUDGE
DESCRIPTOR.message_types_by_name['ObjectYield'] = _OBJECTYIELD
DESCRIPTOR.message_types_by_name['ObjectFollow'] = _OBJECTFOLLOW
DESCRIPTOR.message_types_by_name['ObjectOvertake'] = _OBJECTOVERTAKE
DESCRIPTOR.message_types_by_name['ObjectSidePass'] = _OBJECTSIDEPASS
DESCRIPTOR.message_types_by_name['ObjectAvoid'] = _OBJECTAVOID
DESCRIPTOR.message_types_by_name['ObjectStatus'] = _OBJECTSTATUS
DESCRIPTOR.message_types_by_name['ObjectStatic'] = _OBJECTSTATIC
DESCRIPTOR.message_types_by_name['ObjectDynamic'] = _OBJECTDYNAMIC
DESCRIPTOR.message_types_by_name['ObjectMotionType'] = _OBJECTMOTIONTYPE
DESCRIPTOR.message_types_by_name['ObjectDecisionType'] = _OBJECTDECISIONTYPE
DESCRIPTOR.message_types_by_name['ObjectDecision'] = _OBJECTDECISION
DESCRIPTOR.message_types_by_name['ObjectDecisions'] = _OBJECTDECISIONS
DESCRIPTOR.message_types_by_name['MainStop'] = _MAINSTOP
DESCRIPTOR.message_types_by_name['EmergencyStopHardBrake'] = _EMERGENCYSTOPHARDBRAKE
DESCRIPTOR.message_types_by_name['EmergencyStopCruiseToStop'] = _EMERGENCYSTOPCRUISETOSTOP
DESCRIPTOR.message_types_by_name['MainEmergencyStop'] = _MAINEMERGENCYSTOP
DESCRIPTOR.message_types_by_name['MainCruise'] = _MAINCRUISE
DESCRIPTOR.message_types_by_name['MainChangeLane'] = _MAINCHANGELANE
DESCRIPTOR.message_types_by_name['MainMissionComplete'] = _MAINMISSIONCOMPLETE
DESCRIPTOR.message_types_by_name['MainNotReady'] = _MAINNOTREADY
DESCRIPTOR.message_types_by_name['MainParking'] = _MAINPARKING
DESCRIPTOR.message_types_by_name['MainDecision'] = _MAINDECISION
DESCRIPTOR.message_types_by_name['DecisionResult'] = _DECISIONRESULT
DESCRIPTOR.enum_types_by_name['StopReasonCode'] = _STOPREASONCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TargetLane = _reflection.GeneratedProtocolMessageType('TargetLane', (_message.Message,), {
  'DESCRIPTOR' : _TARGETLANE,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TargetLane)
  })
_sym_db.RegisterMessage(TargetLane)

ObjectIgnore = _reflection.GeneratedProtocolMessageType('ObjectIgnore', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTIGNORE,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectIgnore)
  })
_sym_db.RegisterMessage(ObjectIgnore)

ObjectStop = _reflection.GeneratedProtocolMessageType('ObjectStop', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTSTOP,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectStop)
  })
_sym_db.RegisterMessage(ObjectStop)

ObjectNudge = _reflection.GeneratedProtocolMessageType('ObjectNudge', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTNUDGE,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectNudge)
  })
_sym_db.RegisterMessage(ObjectNudge)

ObjectYield = _reflection.GeneratedProtocolMessageType('ObjectYield', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTYIELD,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectYield)
  })
_sym_db.RegisterMessage(ObjectYield)

ObjectFollow = _reflection.GeneratedProtocolMessageType('ObjectFollow', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTFOLLOW,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectFollow)
  })
_sym_db.RegisterMessage(ObjectFollow)

ObjectOvertake = _reflection.GeneratedProtocolMessageType('ObjectOvertake', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTOVERTAKE,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectOvertake)
  })
_sym_db.RegisterMessage(ObjectOvertake)

ObjectSidePass = _reflection.GeneratedProtocolMessageType('ObjectSidePass', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTSIDEPASS,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectSidePass)
  })
_sym_db.RegisterMessage(ObjectSidePass)

ObjectAvoid = _reflection.GeneratedProtocolMessageType('ObjectAvoid', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTAVOID,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectAvoid)
  })
_sym_db.RegisterMessage(ObjectAvoid)

ObjectStatus = _reflection.GeneratedProtocolMessageType('ObjectStatus', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTSTATUS,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectStatus)
  })
_sym_db.RegisterMessage(ObjectStatus)

ObjectStatic = _reflection.GeneratedProtocolMessageType('ObjectStatic', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTSTATIC,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectStatic)
  })
_sym_db.RegisterMessage(ObjectStatic)

ObjectDynamic = _reflection.GeneratedProtocolMessageType('ObjectDynamic', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTDYNAMIC,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectDynamic)
  })
_sym_db.RegisterMessage(ObjectDynamic)

ObjectMotionType = _reflection.GeneratedProtocolMessageType('ObjectMotionType', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTMOTIONTYPE,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectMotionType)
  })
_sym_db.RegisterMessage(ObjectMotionType)

ObjectDecisionType = _reflection.GeneratedProtocolMessageType('ObjectDecisionType', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTDECISIONTYPE,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectDecisionType)
  })
_sym_db.RegisterMessage(ObjectDecisionType)

ObjectDecision = _reflection.GeneratedProtocolMessageType('ObjectDecision', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTDECISION,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectDecision)
  })
_sym_db.RegisterMessage(ObjectDecision)

ObjectDecisions = _reflection.GeneratedProtocolMessageType('ObjectDecisions', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTDECISIONS,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ObjectDecisions)
  })
_sym_db.RegisterMessage(ObjectDecisions)

MainStop = _reflection.GeneratedProtocolMessageType('MainStop', (_message.Message,), {
  'DESCRIPTOR' : _MAINSTOP,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.MainStop)
  })
_sym_db.RegisterMessage(MainStop)

EmergencyStopHardBrake = _reflection.GeneratedProtocolMessageType('EmergencyStopHardBrake', (_message.Message,), {
  'DESCRIPTOR' : _EMERGENCYSTOPHARDBRAKE,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.EmergencyStopHardBrake)
  })
_sym_db.RegisterMessage(EmergencyStopHardBrake)

EmergencyStopCruiseToStop = _reflection.GeneratedProtocolMessageType('EmergencyStopCruiseToStop', (_message.Message,), {
  'DESCRIPTOR' : _EMERGENCYSTOPCRUISETOSTOP,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.EmergencyStopCruiseToStop)
  })
_sym_db.RegisterMessage(EmergencyStopCruiseToStop)

MainEmergencyStop = _reflection.GeneratedProtocolMessageType('MainEmergencyStop', (_message.Message,), {
  'DESCRIPTOR' : _MAINEMERGENCYSTOP,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.MainEmergencyStop)
  })
_sym_db.RegisterMessage(MainEmergencyStop)

MainCruise = _reflection.GeneratedProtocolMessageType('MainCruise', (_message.Message,), {
  'DESCRIPTOR' : _MAINCRUISE,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.MainCruise)
  })
_sym_db.RegisterMessage(MainCruise)

MainChangeLane = _reflection.GeneratedProtocolMessageType('MainChangeLane', (_message.Message,), {
  'DESCRIPTOR' : _MAINCHANGELANE,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.MainChangeLane)
  })
_sym_db.RegisterMessage(MainChangeLane)

MainMissionComplete = _reflection.GeneratedProtocolMessageType('MainMissionComplete', (_message.Message,), {
  'DESCRIPTOR' : _MAINMISSIONCOMPLETE,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.MainMissionComplete)
  })
_sym_db.RegisterMessage(MainMissionComplete)

MainNotReady = _reflection.GeneratedProtocolMessageType('MainNotReady', (_message.Message,), {
  'DESCRIPTOR' : _MAINNOTREADY,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.MainNotReady)
  })
_sym_db.RegisterMessage(MainNotReady)

MainParking = _reflection.GeneratedProtocolMessageType('MainParking', (_message.Message,), {
  'DESCRIPTOR' : _MAINPARKING,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.MainParking)
  })
_sym_db.RegisterMessage(MainParking)

MainDecision = _reflection.GeneratedProtocolMessageType('MainDecision', (_message.Message,), {
  'DESCRIPTOR' : _MAINDECISION,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.MainDecision)
  })
_sym_db.RegisterMessage(MainDecision)

DecisionResult = _reflection.GeneratedProtocolMessageType('DecisionResult', (_message.Message,), {
  'DESCRIPTOR' : _DECISIONRESULT,
  '__module__' : 'modules.planning.proto.decision_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DecisionResult)
  })
_sym_db.RegisterMessage(DecisionResult)


_MAINDECISION.fields_by_name['change_lane']._options = None
_MAINDECISION.fields_by_name['target_lane']._options = None
# @@protoc_insertion_point(module_scope)
